@@ -9,13 +9,13 @@ from requests.adapters import HTTPAdapter
 from requests_futures.sessions import FuturesSession
 from urllib3 import Retry
 
-from pymoodle_jku.Classes.course import Course
-from pymoodle_jku.Classes.evaluation import Evaluation
-from pymoodle_jku.Classes.events import Event
-from pymoodle_jku.Classes.exceptions import NotLoggedInError, LoginError
-from pymoodle_jku.Client.html_parser import LoginPage, MyPage, \
+from pymoodle_jku.classes.course import Course
+from pymoodle_jku.classes.evaluation import Evaluation
+from pymoodle_jku.classes.events import Event
+from pymoodle_jku.classes.exceptions import NotLoggedInError, LoginError
+from pymoodle_jku.client.html_parser import LoginPage, MyPage, \
     ValuationOverviewPage, CoursePage, ValuationPage
-from pymoodle_jku.Utils.printing import print_exc
+from pymoodle_jku.utils.printing import print_exc
 
 
 def requests_retry_session(
@@ -188,13 +188,16 @@ class MoodleClient:
         else:
             headers = {'Content-type': 'application/json'}
             response = self.session.post(
-                f'https://moodle.jku.at/jku/lib/ajax/service.php?sesskey={self.sesskey}&info=core_course_get_enrolled_courses_by_timeline_classification',
+                f'https://moodle.jku.at/jku/lib/ajax/service.php?sesskey={self.sesskey}',
                 data=json.dumps(
                     [{"index": 0, "methodname": "core_course_get_enrolled_courses_by_timeline_classification",
-                      "args": {"offset": 0, "limit": 0, "classification": "all", "sort": "fullname",
-                               "customfieldname": "", "customfieldvalue": ""}}]), headers=headers)
+                      "args": {"offset": 0, "limit": 0, "classification": "all", "sort": "fullname"}},
+                     {"index": 1, "methodname": "core_course_get_enrolled_courses_by_timeline_classification",
+                      "args": {"offset": 0, "limit": 0, "classification": "hidden", "sort": "fullname"}}]),
+                headers=headers)
 
-            courses_json = json.loads(response.content.decode('utf-8'))[0]['data']['courses']
+            courses_json = json.loads(response.content.decode('utf-8'))[0]['data']['courses'] + \
+                           json.loads(response.content.decode('utf-8'))[1]['data']['courses']
 
             if load_pages is False:
                 for c in courses_json:
@@ -233,7 +236,7 @@ class MoodleClient:
         :param limit: Max amount of entries to load.
         :return: A List of Calendar Events.
         """
-        url = f'https://moodle.jku.at/jku/lib/ajax/service.php?sesskey={self.sesskey}&info=core_calendar_get_action_events_by_timesort'
+        url = f'https://moodle.jku.at/jku/lib/ajax/service.php?sesskey={self.sesskey}'
         data = [{"index": 0, "methodname": "core_calendar_get_action_events_by_timesort",
                  "args": {"limitnum": limit, "timesortfrom": int(time.time()), "limittononsuspendedevents": True}}]
         response = self.session.post(url, json=data)
@@ -266,8 +269,8 @@ class MoodleClient:
 
         :raises Exception: If user isn't logged in.
         """
-        if r.headers.get('Content-Type') == 'application/json; charset=utf-8' or r.headers.get(
-                'Content-Type') == 'application/json':
+        if (r.headers.get('Content-Type') == 'application/json; charset=utf-8' or r.headers.get(
+                'Content-Type') == 'application/json') and 'moodle.jku.at' in r.url:
             j = r.json()
             if type(j) is list and type(j[0]) is dict and 'error' in j[0] and j[0]['error'] is True:
                 raise NotLoggedInError('Please Login')
@@ -288,7 +291,7 @@ class MoodleClient:
         return r
 
     def __init__(self, pool_executor=ThreadPoolExecutor(max_workers=4)):
-        """Initializes a MoodleClient, a Client can load Data from Moodle.
+        """Initializes a MoodleClient, a client can load Data from Moodle.
 
         :param pool_executor: A instance of a ThreadPoolExecutor.
         """
