@@ -1,8 +1,46 @@
+import signal
+import sys
 import argparse
 
 import argcomplete
 
-from pymoodle_jku.Utils import basic
+
+def interuppt_handler(signum, frame):
+    sys.exit(0)
+
+
+def check_update():
+    from pymoodle_jku.utils.config_data import config
+    updates = config.getboolean('UpdateInfo')
+    if updates:
+        from importlib.metadata import version
+        import requests
+        from requests import RequestException
+        from packaging.version import parse as parse_version
+        from sty import fg
+        from json.decoder import JSONDecodeError
+        from importlib.metadata import PackageNotFoundError
+
+        package = 'pymoodle-jku'
+        repo_url = f'LeLunZ/{package}-linz'
+        try:
+            installed_version = version(package)
+            response = requests.get(f'https://api.github.com/repos/{repo_url}/releases/latest')
+            current_version = response.json()['tag_name']
+            c_version = parse_version(current_version)
+            i_version = parse_version(installed_version)
+            if i_version < c_version:
+                print(fg.li_red + 'New Version is available!' + fg.rs)
+                print(
+                    fg.li_red + 'Install with python3 >= 3.8 pip: ' + fg.rs + fg.li_blue + f'pip install -U pymoodle-jku=={current_version}' + fg.rs)
+                print(
+                    fg.li_red + 'Use pip3 if you have python2 on the system: ' + fg.rs + fg.li_green + f'pip3 install -U pymoodle-jku=={current_version}' + fg.rs)
+        except RequestException:
+            pass
+        except JSONDecodeError:
+            pass
+        except PackageNotFoundError:
+            pass
 
 
 def main():
@@ -74,13 +112,32 @@ def main():
     argcomplete.autocomplete(parser)
 
     args = parser.parse_args()
+
     # imports are here because autocomplete is faster that way
+    import atexit
+    import sys
 
-    from pymoodle_jku.Client.client import MoodleClient
-    from pymoodle_jku.Utils import grades, downloading, timetable, config
-    from pymoodle_jku.Utils import login
+    from sty import fg
+
+    from pymoodle_jku.utils import basic
+    from pymoodle_jku.client.client import MoodleClient
+    from pymoodle_jku.utils import grades, downloading, timetable, config
+    from pymoodle_jku.utils import login
+    from pymoodle_jku.classes.exceptions import LoginError
+    from pymoodle_jku.utils.printing import yn_question
+
+    atexit.register(check_update)
+    signal.signal(signal.SIGINT, interuppt_handler)
+
+    supported_version = (3, 8)
+    supported_version_str = 'Python >=3.8'
+    if sys.version_info < supported_version:
+        print(fg.li_red + 'You aren\'t running a supported Python version. There could be some bugs while running.')
+        print(f'For full support install {supported_version_str}' + fg.rs)
+        continue_pymoodle = yn_question(input(fg.li_blue + 'Do you still want to continue? (y/n): ' + fg.rs))
+        if not continue_pymoodle:
+            return 0
 
-    # first use tools
     if 'utility' not in args or args.utility is None:
         all_parser = [config_parser, grades_parser, download_parser, timeline_parser, parser]
         return basic.main(all_parser)
@@ -93,7 +150,7 @@ def main():
                                            threads=args.threads)
 
         if client is None:
-            raise Exception('Try again. Login Failed.')
+            raise LoginError('Try again. Login Failed.')
         if args.utility == 'grades':
             return grades.main(client, args)
         elif args.utility == 'download':
@@ -105,4 +162,7 @@ def main():
 
 
 if __name__ == '__main__':
-    exit(main())
+    try:
+        sys.exit(main())
+    except KeyboardInterrupt:
+        sys.exit(0)
